0.9.9 API documentation: functions.hpp Source File

| 0.9.9 API documentation

- Main Page
- Modules
- Files

- File List

functions.hpp
Go to the documentation of this file.
1
14 #pragma once
15
16 // Dependencies
17 #include "../detail/setup.hpp"
18 #include "../detail/qualifier.hpp"
19 #include "../detail/type_vec2.hpp"
20
21 #if GLM_MESSAGES == GLM_ENABLE && !defined(GLM_EXT_INCLUDED)
22 # ifndef GLM_ENABLE_EXPERIMENTAL
23 # pragma message("GLM: GLM_GTX_functions is an experimental extension and may change in the future. Use #define GLM_ENABLE_EXPERIMENTAL before including it, if you really want to use it.")
24 # else
25 # pragma message("GLM: GLM_GTX_functions extension included")
26 # endif
27 #endif
28
29 namespace glm
30 {
33
37 template<typename T>
38 GLM_FUNC_DECL T gauss(
39 T x,
40 T ExpectedValue,
41 T StandardDeviation);
42
46 template<typename T, qualifier Q>
47 GLM_FUNC_DECL T gauss(
48 vec<2, T, Q> const& Coord,
49 vec<2, T, Q> const& ExpectedValue,
50 vec<2, T, Q> const& StandardDeviation);
51
53 }//namespace glm
54
55 #include "functions.inl"
56
glm::gauss
GLM_FUNC_DECL T gauss(vec< 2, T, Q > const &Coord, vec< 2, T, Q > const &ExpectedValue, vec< 2, T, Q > const &StandardDeviation)
2D gauss function
glm
Definition: common.hpp:20